==> drd-4.1.0-rc3.tar.gz: drd/modules/drd_eca/src/Plugin/ECA/Event/DrdEvent.php <==
<?php

namespace Drupal\drd_eca\Plugin\ECA\Event;

use Drupal\drd\Event\DrdActionFinish;
use Drupal\drd\Event\DrdActionStart;
use Drupal\drd\Event\DrdBase;
use Drupal\drd\Event\DrdEvents;
use Drupal\eca\Plugin\ECA\Event\EventBase;

/**
 * Plugin implementation of the ECA Events drom DRD.
 *
 * @EcaEvent(
 *   id = "drd",
 *   deriver = "Drupal\drd_eca\Plugin\ECA\Event\DrdEventDeriver"
 * )
 */
class DrdEvent extends EventBase {

  /**
   * Return the actions of the plugin.
   *
   * @return array[]
   *   The actions of the plugin.
   */
  public static function definitions(): array {
    return [
      'drd_eca_action_started' => [
        'label' => 'DRD: Action started',
        'event_name' => DrdEvents::ACTION_STARTED,
        'event_class' => DrdActionStart::class,
      ],
      'drd_eca_action_finished' => [
        'label' => 'DRD: Action finished',
        'event_name' => DrdEvents::ACTION_FINISHED,
        'event_class' => DrdActionFinish::class,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function buildEventData(): array {
    $event = $this->event;
    $data = [];
    if ($event instanceof DrdBase) {
      $action = $event->getAction();
      $data += [
        'drd' => [
          'action' => $action->getPluginId(),
        ],
      ];
      $entity = $event->getEntity();
      if ($entity !== NULL) {
        $data += [
          'entity' => $entity,
        ];
      }
    }
    $data += parent::buildEventData();
    return $data;
  }

  /**
   * {@inheritdoc}
   */
  public function getData(string $key): mixed {
    $event = $this->event;
    if ($event instanceof DrdBase) {
      if ($key === 'drd') {
        $action = $event->getAction();
        return [
          'action' => $action->getPluginId(),
        ];
      }
      if ($key === 'entity' && ($entity = $event->getEntity())) {
        return $entity;
      }
    }
    return parent::getData($key);
  }

}

==> drd-4.1.1.tar.gz: drd/modules/drd_eca/src/Plugin/ECA/Event/DrdEvent.php <==
<?php

namespace Drupal\drd_eca\Plugin\ECA\Event;

use Drupal\drd\Event\DrdActionFinish;
use Drupal\drd\Event\DrdActionStart;
use Drupal\drd\Event\DrdBase;
use Drupal\drd\Event\DrdEvents;
use Drupal\eca\Plugin\ECA\Event\EventBase;

/**
 * Plugin implementation of the ECA Events drom DRD.
 *
 * @EcaEvent(
 *   id = "drd",
 *   deriver = "Drupal\drd_eca\Plugin\ECA\Event\DrdEventDeriver",
 *   eca_version_introduced = "4.1.0"
 * )
 */
class DrdEvent extends EventBase {

  /**
   * Return the actions of the plugin.
   *
   * @return array[]
   *   The actions of the plugin.
   */
  public static function definitions(): array {
    return [
      'drd_eca_action_started' => [
        'label' => 'DRD: Action started',
        'event_name' => DrdEvents::ACTION_STARTED,
        'event_class' => DrdActionStart::class,
      ],
      'drd_eca_action_finished' => [
        'label' => 'DRD: Action finished',
        'event_name' => DrdEvents::ACTION_FINISHED,
        'event_class' => DrdActionFinish::class,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function buildEventData(): array {
    $event = $this->event;
    $data = [];
    if ($event instanceof DrdBase) {
      $action = $event->getAction();
      $data += [
        'drd' => [
          'action' => $action->getPluginId(),
        ],
      ];
      $entity = $event->getEntity();
      if ($entity !== NULL) {
        $data += [
          'entity' => $entity,
        ];
      }
    }
    $data += parent::buildEventData();
    return $data;
  }

  /**
   * {@inheritdoc}
   */
  public function getData(string $key): mixed {
    $event = $this->event;
    if ($event instanceof DrdBase) {
      if ($key === 'drd') {
        $action = $event->getAction();
        return [
          'action' => $action->getPluginId(),
        ];
      }
      if ($key === 'entity' && ($entity = $event->getEntity())) {
        return $entity;
      }
    }
    return parent::getData($key);
  }

}
